==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/s3control/kotlin/outputs/StorageLensConfigurationStorageLensConfigurationAccountLevelBucketLevelPrefixLevelStorageMetricsSelectionCriteria.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3control.kotlin.outputs

import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property delimiter The delimiter of the selection criteria being used.
 * @property maxDepth The max depth of the selection criteria.
 * @property minStorageBytesPercentage The minimum number of storage bytes percentage whose metrics will be selected.
 */
public data class
StorageLensConfigurationStorageLensConfigurationAccountLevelBucketLevelPrefixLevelStorageMetricsSelectionCriteria(
    public val delimiter: String? = null,
    public val maxDepth: Int? = null,
    public val minStorageBytesPercentage: Double? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.s3control.outputs.StorageLensConfigurationStorageLensConfigurationAccountLevelBucketLevelPrefixLevelStorageMetricsSelectionCriteria):
            StorageLensConfigurationStorageLensConfigurationAccountLevelBucketLevelPrefixLevelStorageMetricsSelectionCriteria =
            StorageLensConfigurationStorageLensConfigurationAccountLevelBucketLevelPrefixLevelStorageMetricsSelectionCriteria(
                delimiter = javaType.delimiter().map({ args0 -> args0 }).orElse(null),
                maxDepth = javaType.maxDepth().map({ args0 -> args0 }).orElse(null),
                minStorageBytesPercentage = javaType.minStorageBytesPercentage().map({ args0 ->
                    args0
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/s3control/kotlin/outputs/StorageLensConfigurationStorageLensConfigurationAccountLevelBucketLevelPrefixLevelStorageMetricsSelectionCriteria.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3control.kotlin.outputs

import kotlin.Double
import kotlin.Int
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property delimiter The delimiter of the selection criteria being used.
 * @property maxDepth The max depth of the selection criteria.
 * @property minStorageBytesPercentage The minimum number of storage bytes percentage whose metrics will be selected.
 */
public data class
StorageLensConfigurationStorageLensConfigurationAccountLevelBucketLevelPrefixLevelStorageMetricsSelectionCriteria(
    public val delimiter: String? = null,
    public val maxDepth: Int? = null,
    public val minStorageBytesPercentage: Double? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.s3control.outputs.StorageLensConfigurationStorageLensConfigurationAccountLevelBucketLevelPrefixLevelStorageMetricsSelectionCriteria): StorageLensConfigurationStorageLensConfigurationAccountLevelBucketLevelPrefixLevelStorageMetricsSelectionCriteria =
            StorageLensConfigurationStorageLensConfigurationAccountLevelBucketLevelPrefixLevelStorageMetricsSelectionCriteria(
                delimiter = javaType.delimiter().map({ args0 -> args0 }).orElse(null),
                maxDepth = javaType.maxDepth().map({ args0 -> args0 }).orElse(null),
                minStorageBytesPercentage = javaType.minStorageBytesPercentage().map({ args0 ->
                    args0
                }).orElse(null),
            )
    }
}
